@@ -10,7 +10,8 @@ import requests
 class DataApi:
 
     __token = ''
-    __http_url = 'http://210.22.185.58:7788'
+    __http_url = 'http://210.22.185.58:7788/route'
+    #__http_url = 'http://localhost:5000'
 
     def __init__(self, token, timeout=30):
         """
@@ -22,7 +23,7 @@ class DataApi:
         self.__token = token
         self.__timeout = timeout
 
-    def query(self, api_name, fields='', **kwargs):
+    def query(self, api_name, fields=[], **kwargs):
         req_params = {
             'api_name': api_name,
             'token': self.__token,
@@ -30,6 +31,8 @@ class DataApi:
             'fields': fields
         }
 
+        print(req_params)
+
         res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout)
         if res:
             result = json.loads(res.text)
